@@ -90,7 +90,7 @@ class tentext:
         #print(sequences[:5])
         return self.predictors, self._label, self.maxSequenceLen, self.totalwords
     
-    def configmodel(self,seq_text, lstmlayer, activation):
+    def configmodel(self,seq_text, lstmlayer, activation, dropout):
     
         '''Configures the neural network'''
         self.predictors, self._label, self.maxSequenceLen, self.totalwords = seq_text
@@ -99,6 +99,7 @@ class tentext:
             activation = 'softmax'
         model = models.Sequential()
         model.add(layers.Embedding(self.totalwords, 64,input_length=self.maxSequenceLen - 1))
+        model.add(Dropout(dropout))
         model.add(layers.LSTM(lstmlayer))
         model.add(layers.Dense(self.totalwords - 500, activation=activation))
         model.add(layers.Dense(self.totalwords, activation=activation))
@@ -118,7 +119,7 @@ class tentext:
         self.batch = batch
     
         '''Sets the training parameters and fits the model to the data'''
-        model2 = self.model.compile(loss=loss, optimizer=optimizer, metrics=[metrics])
+        self.model.compile(loss=loss, optimizer=optimizer, metrics=[metrics])
         history = self.model.fit(self.predictors, self._label, epochs=epochs, batch_size= batch, verbose = verbose,
                         callbacks=[EarlyStopping(monitor='loss', patience=patience,
                                                  restore_best_weights=True)])
